<?php

if ( !defined( 'ABSPATH' ) ) {
	exit;
}

if ( !class_exists( 'WCOT_Order_Tags_Set' ) ) {

	class WCOT_Order_Tags_Set {

		public function __construct() {

			add_action( 'woocommerce_new_order', array( $this, 'set_tags' ), 20, 2 ); // Order placed - woocommerce_new_order action hook as used by both website and WooCommerce API, this hook is also conditioned off via current_action() in set_tags(), 20 priority used incase any other plugins make changes to order at default priority, core WooCommerce passes the $order object but some plugins and the WooCommerce legacy APIs hook into this but do not pass the order object, for these set_tags() won't occur due to the conditions within the function with $order defaulting to false - which is okay as the core WooCommerce do_action with the $order object passed ensures the tags get set correctly
			add_action( 'woocommerce_update_order', array( $this, 'set_tags' ), 20, 2 ); // Order update - woocommerce_update_order action hook as used by both website and WooCommerce API, this hook is also conditioned off via current_action() in set_tags(), 20 priority used incase any other plugins make changes to order at default priority, core WooCommerce passes the $order object but some plugins and the WooCommerce legacy APIs hook into this but do not pass the order object, for these set_tags() won't occur due to the conditions within the function with $order defaulting to false - which is okay as the core WooCommerce do_action with the $order object passed ensures the tags get set correctly
			add_filter( 'wcs_renewal_order_created', array( $this, 'set_tags_order_subscription_renewal' ), 20, 2 ); // Order subscription renewal - this hook is also conditioned off via current_filter() in set_tags(), 20 priority used incase any other plugins make changes to order at default priority, this is how we determine a new order from a subscription renewal has been created, it is effectively WooCommerce Subscription's equivalent of woocommerce_new_order which it does not use, allowing us to set tags if the set if order subscription renewal option is enabled
			add_action( 'admin_init', array( $this, 'set_tags_bulk' ) ); // Triggered via wcot_order_tags_set_tags_bulk query var

		}

		public function set_tags( $order_id, $order = false ) {

			// Passed $order above is extremely important, this will have been modified by core WooCommerce and potentially other plugins, if this is not used and instead got via wc_get_order( $order_id ) it will not be setup fully yet with the order data depending on the action/filter hook, we must use the passed order object

			if ( 'shop_order' == get_post_type( $order_id ) ) {

				// The condition above ensures only bonafide orders (including subscription renewals as these are still shop_order) get tags set but not shop_order_refund, shop_subscription, etc and without this the WC_Order functions used below may cause fatal errors too as they might not exist on non shop_order types

				$order_tags = wcot_order_tags_get_all_order_tags();

				if ( !empty( $order ) && !empty( $order_tags ) ) {

					$shipping_zones = WC_Shipping_Zones::get_zones();

					if ( !empty( $shipping_zones ) ) {

						$shipping_methods = array_map(
							function( $shipping_zone ) {
								return $shipping_zone['shipping_methods'];
							},
							$shipping_zones
						);

					} else {

						$shipping_methods = array();

					}

					$order_customer = $order->get_customer_id();
					$order_customer_user = get_userdata( $order_customer );
					$order_customer_roles = array();

					if ( !empty( $order_customer_user ) ) {

						if ( isset( $order_customer_user->roles ) ) { // Stops PHP notice is no user role as guest

							$order_customer_roles = $order_customer_user->roles;

						}

					}

					$order_customer_orders_count = wc_get_customer_order_count( $order_customer );
					$order_items = $order->get_items();
					$order_item_count = $order->get_item_count( 'line_item' ); // Product type order items are line_item, others like coupon, refund, shipping, tax return a different type, this is useful as we don't want non-products to be counted towards the order item count
					$order_payment_method = $order->get_payment_method();
					$order_shipping_methods = $order->get_shipping_methods();
					$order_shipping_method_instance_id = false; // Populated later but remains false if no shipping method for order (e.g. virtual)
					$order_shipping_zone = array();
					$order_status = $order->get_status();
					$order_total = $order->get_total();

					if ( 'wcs_renewal_order_created' == current_filter() ) {

						$subscription_id = get_post_meta( $order_id, '_subscription_renewal', true );

						if ( !empty( $subscription_id ) ) {

							$subscription = wc_get_order( $subscription_id ); // Subscriptions (shop_subscription post type) are still gettable via wc_get_order

							// If this is a subscription renewal order there are parts of the order object that won't be populated yet at the time wcs_renewal_order_created is triggered, the ones which were found to be unavailable at that time we grab the data from the subscription instead below

							$order_items = $subscription->get_items();
							$order_item_count = $subscription->get_item_count( 'line_item' );
							$order_payment_method = $subscription->get_payment_method();
							$order_shipping_methods = $subscription->get_shipping_methods();
							$order_total = $subscription->get_total();

						}

					}

					if ( !empty( $order_shipping_methods ) ) {

						// Note that this is an array but there is always only one shipping method

						foreach ( $order_shipping_methods as $order_shipping_method ) {

							$order_shipping_method_id = $order_shipping_method->get_method_id();
							$order_shipping_method_instance_id = $order_shipping_method->get_instance_id();
							break;

						}

					}

					if ( !empty( $shipping_zones ) ) {

						foreach ( $shipping_zones as $shipping_zone ) {

							$shipping_zone_shipping_methods = $shipping_zone['shipping_methods'];

							foreach ( $shipping_zone_shipping_methods as $shipping_zone_shipping_method ) {

								if ( $shipping_zone_shipping_method->get_instance_id() == $order_shipping_method_instance_id ) {
	
									$order_shipping_zone = $shipping_zone['zone_id'];
									break 2;
	
								}
	
							}
	
						}
	
					}

					// Loop order tags

					foreach ( $order_tags as $order_tag ) {

						// Set on order placed

						$set_on_order_placed = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_on_order_placed', true );

						// Define maybe set tag

						$maybe_set_tag = false;

						if ( 'on' == $set_on_order_placed && 'woocommerce_new_order' == current_action() ) {

							$maybe_set_tag = true;

						}

						// Set on order update

						$set_on_order_update = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_on_order_update', true );

						if ( 'on' == $set_on_order_update && 'woocommerce_update_order' == current_action() ) {

							$maybe_set_tag = true;

						}

						// Set on order subscription renewal

						$set_on_order_subscription_renewal = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_on_order_subscription_renewal', true );

						if ( 'on' == $set_on_order_subscription_renewal && 'wcs_renewal_order_created' == current_filter() ) {

							$maybe_set_tag = true;

						}

						// Set anyway due to set tags bulk

						if ( isset( $_GET['wcot_order_tags_set_tags_bulk'] ) ) {

							if ( current_user_can( 'manage_woocommerce' ) ) {

								$set_tags_bulk = sanitize_text_field( $_GET['wcot_order_tags_set_tags_bulk'] );

								if ( '1' == $set_tags_bulk || '2' == $set_tags_bulk ) {

									$maybe_set_tag = true;

								}

							}

						}

						// Maybe set tag

						if ( true == $maybe_set_tag ) {

							// Set if array

							$set_if = array();
							$set_if['customer'] = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_customer', true );
							$set_if['customer_order_count'] = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_customer_order_count', true );
							$set_if['customer_role'] = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_customer_role', true );
							$set_if['item_count'] = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_item_count', true );
							$set_if['meta_data'] = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_meta_data', true );
							$set_if['order_status'] = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_order_status', true );
							$set_if['order_total'] = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_order_total', true );
							$set_if['payment_method'] = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_payment_method', true );
							$set_if['product'] = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_product', true );
							$set_if['product_category'] = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_product_category', true );
							$set_if['product_meta_data'] = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_product_meta_data', true );
							$set_if['product_tag'] = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_product_tag', true );
							$set_if['shipping_method'] = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_shipping_method', true );
							$set_if['shipping_method_instance'] = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_shipping_method_instance', true );
							$set_if['shipping_zone'] = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_shipping_zone', true );

							$set_tag_conditions_met = array();

							// Set if customer

							if ( 'on' == $set_if['customer'] && !empty( $order_customer ) ) {

								if ( false !== get_userdata( $order_customer ) ) { // Checks the customer still exists as might have been deleted (without this as it is still in the term meta until updated the tag would still get set)

									$set_if_customer_value = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_customer_value', true );
									$set_if_customer_value = ( !empty( $set_if_customer_value ) ? $set_if_customer_value : array() ); // For empty array

									if ( in_array( $order_customer, $set_if_customer_value ) ) {

										$set_tag_conditions_met['customer'] = true;

									}

								}

							}

							// Set if customer order count

							if ( 'on' == $set_if['customer_order_count'] ) {

								$set_if_customer_order_count_operator = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_customer_order_count_operator', true );
								$set_if_customer_order_count_value = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_customer_order_count_value', true );

								if ( $this->set_tags_operator( $order_customer_orders_count, $set_if_customer_order_count_operator, $set_if_customer_order_count_value ) ) {

									$set_tag_conditions_met['customer_order_count'] = true;

								}

							}

							// Set if customer role

							if ( 'on' == $set_if['customer_role'] && !empty( $order_customer ) ) {

								if ( false !== get_userdata( $order_customer ) ) { // Checks the customer still exists as might have been deleted (without this as it is still in the term meta until updated the tag would still get set)

									$set_if_customer_role_value = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_customer_role_value', true );
									$set_if_customer_role_value = ( !empty( $set_if_customer_role_value ) ? $set_if_customer_role_value : array() ); // For empty array

									foreach ( $order_customer_roles as $order_customer_role ) {

										if ( in_array( $order_customer_role, $set_if_customer_role_value ) ) {

											$set_tag_conditions_met['customer_role'] = true;

										}

									}

								}

							}

							// Set if item count

							if ( 'on' == $set_if['item_count'] ) {

								$set_if_item_count_operator = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_item_count_operator', true );
								$set_if_item_count_value = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_item_count_value', true );

								if ( $this->set_tags_operator( $order_item_count, $set_if_item_count_operator, $set_if_item_count_value ) ) {

									$set_tag_conditions_met['item_count'] = true;

								}

							}

							// Set if meta data

							if ( 'on' == $set_if['meta_data'] ) {

								$set_if_meta_data_value = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_meta_data_value', true );

								if ( !empty( $set_if_meta_data_value ) ) {

									$set_if_meta_datas = explode( PHP_EOL, $set_if_meta_data_value );
									$set_if_meta_datas_count = 0;

									foreach ( $set_if_meta_datas as $set_if_meta_data ) {

										$set_if_meta_data = explode( '|', $set_if_meta_data, 3 );
										$set_if_meta_data_get = get_post_meta( $order_id, $set_if_meta_data[0], true );

										if ( '' !== $set_if_meta_data_get ) { // Not an !is_empty as value might be 0

											if ( true == $this->set_tags_operator( trim( $set_if_meta_data_get ), trim( $set_if_meta_data[1] ), trim( $set_if_meta_data[2] ) ) ) {

												$set_if_meta_datas_count++;
	
											}

										}

									}

									if ( count( $set_if_meta_datas ) == $set_if_meta_datas_count ) { // Ensures all meta data conditions specified are met to set the tag

										$set_tag_conditions_met['meta_data'] = true;

									}

								}

							}

							// Set if order status

							if ( 'on' == $set_if['order_status'] && !empty( $order_status ) ) {

								$set_if_order_status_value = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_order_status_value', true );
								$set_if_order_status_value = ( !empty( $set_if_order_status_value ) ? $set_if_order_status_value : array() ); // For empty array

								if ( in_array( 'wc-' . $order_status, $set_if_order_status_value ) ) { // wc- prefix added as $order_status is without wc- prefix and this compares to data with the wc- prefix

									$set_tag_conditions_met['order_status'] = true;

								}

							}

							// Set if order total

							if ( 'on' == $set_if['order_total'] ) {

								$set_if_order_total_operator = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_order_total_operator', true );
								$set_if_order_total_value = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_order_total_value', true );

								if ( $this->set_tags_operator( $order_total, $set_if_order_total_operator, $set_if_order_total_value ) ) {

									$set_tag_conditions_met['order_total'] = true;

								}

							}

							// Set if payment method

							if ( 'on' == $set_if['payment_method'] && !empty( $order_payment_method ) ) {

								$set_if_payment_method_value = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_payment_method_value', true );
								$set_if_payment_method_value = ( !empty( $set_if_payment_method_value ) ? $set_if_payment_method_value : array() );

								if ( in_array( $order_payment_method, $set_if_payment_method_value ) ) {

									$set_tag_conditions_met['payment_method'] = true;

								}

							}

							// Set if product

							if ( 'on' == $set_if['product'] && !empty( $order_items ) ) {

								$set_if_product_value = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_product_value', true );
								$set_if_product_value = ( !empty( $set_if_product_value ) ? $set_if_product_value : array() );

								foreach ( $order_items as $order_item ) {

									$order_item_type = $order_item->get_type();

									if ( 'line_item' == $order_item_type ) { // Product based order items are line_item, others like coupon, refund, shipping, tax return a different type

										$order_item_product_id = $order_item->get_product_id();

										if ( in_array( $order_item_product_id, $set_if_product_value ) ) {

											$set_tag_conditions_met['product'] = true;

										}

									}

								}

							}

							// Set if product category

							if ( 'on' == $set_if['product_category'] && !empty( $order_items ) ) {

								$set_if_product_category_value = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_product_category_value', true );
								$set_if_product_category_value = ( !empty( $set_if_product_category_value ) ? $set_if_product_category_value : array() );

								foreach ( $order_items as $order_item ) {

									$order_item_type = $order_item->get_type();

									if ( 'line_item' == $order_item_type ) { // Product based order items are line_item, others like coupon, refund, shipping, tax return a different type

										$order_item_product_id = $order_item->get_product_id();
										$order_item_product_categories = get_the_terms( $order_item_product_id, 'product_cat' );

										if ( !empty( $order_item_product_categories ) ) {

											foreach ( $order_item_product_categories as $order_item_product_category ) {

												if ( in_array( $order_item_product_category->term_id, $set_if_product_category_value ) ) {

													$set_tag_conditions_met['product_category'] = true;

												}

											}

										}

									}

								}

							}

							// Set if product meta data

							if ( 'on' == $set_if['product_meta_data'] && !empty( $order_items ) ) {

								$set_if_product_meta_data_value = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_product_meta_data_value', true );

								if ( !empty( $set_if_product_meta_data_value ) ) {

									$set_if_product_meta_datas = explode( PHP_EOL, $set_if_product_meta_data_value );
									$set_if_product_meta_datas_count = 0;

									foreach ( $order_items as $order_item ) {

										$order_item_type = $order_item->get_type();

										if ( 'line_item' == $order_item_type ) { // Product based order items are line_item, others like coupon, refund, shipping, tax return a different type

											$order_item_product_id = $order_item->get_product_id();
											$order_item_variation_id = $order_item->get_variation_id();

											foreach ( $set_if_product_meta_datas as $set_if_product_meta_data ) {

												$set_if_product_meta_data = explode( '|', $set_if_product_meta_data, 3 );

												if ( (int) $order_item_variation_id > 0 ) {

													$set_if_product_meta_data_get = get_post_meta( $order_item_variation_id, $set_if_product_meta_data[0], true );

													if ( '' == $set_if_product_meta_data_get ) {

														$set_if_product_meta_data_get = get_post_meta( $order_item_product_id, $set_if_product_meta_data[0], true );

													}

												} else {

													$set_if_product_meta_data_get = get_post_meta( $order_item_product_id, $set_if_product_meta_data[0], true );

												}

												if ( '' !== $set_if_product_meta_data_get ) { // Not an !is_empty as value might be 0

													if ( true == $this->set_tags_operator( trim( $set_if_product_meta_data_get ), trim( $set_if_product_meta_data[1] ), trim( $set_if_product_meta_data[2] ) ) ) {

														$set_if_product_meta_datas_count++;

													}

												}

											}

										}

									}

									if ( count( $set_if_product_meta_datas ) == $set_if_product_meta_datas_count ) { // Ensures all product meta data conditions specified are met to set the tag

										$set_tag_conditions_met['product_meta_data'] = true;

									}

								}

							}

							// Set if product tag

							if ( 'on' == $set_if['product_tag'] && !empty( $order_items ) ) {

								$set_if_product_tag_value = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_product_tag_value', true );
								$set_if_product_tag_value = ( !empty( $set_if_product_tag_value ) ? $set_if_product_tag_value : array() );

								foreach ( $order_items as $order_item ) {

									$order_item_type = $order_item->get_type();

									if ( 'line_item' == $order_item_type ) { // Product based order items are line_item, others like coupon, refund, shipping, tax return a different type

										$order_item_product_id = $order_item->get_product_id();
										$order_item_product_tags = get_the_terms( $order_item_product_id, 'product_tag' );

										if ( !empty( $order_item_product_tags ) ) {

											foreach ( $order_item_product_tags as $order_item_product_tag ) {

												if ( in_array( $order_item_product_tag->term_id, $set_if_product_tag_value ) ) {

													$set_tag_conditions_met['product_tag'] = true;

												}

											}

										}

									}

								}

							}

							// Set if shipping method

							if ( 'on' == $set_if['shipping_method'] && !empty( $order_shipping_methods ) ) {

								$set_if_shipping_method_value = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_shipping_method_value', true );
								$set_if_shipping_method_value = ( !empty( $set_if_shipping_method_value ) ? $set_if_shipping_method_value : array() );

								foreach ( $shipping_methods as $shipping_method ) {

									foreach ( $shipping_method as $shipping_method_object ) {

										if ( $shipping_method_object->id == $order_shipping_method_id ) { // Checks the method still exists as might have been deleted (without this as it is still in the term meta until updated the tag would still get set)

											foreach ( $order_shipping_methods as $order_shipping_method ) {

												if ( in_array( $order_shipping_method_id, $set_if_shipping_method_value ) ) {

													$set_tag_conditions_met['shipping_method'] = true;

												}

											}

										}

									}

								}

							}

							// Set if shipping method instance

							if ( 'on' == $set_if['shipping_method_instance'] && !empty( $order_shipping_methods ) ) {

								$set_if_shipping_method_instance_value = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_shipping_method_instance_value', true );
								$set_if_shipping_method_instance_value = ( !empty( $set_if_shipping_method_instance_value ) ? $set_if_shipping_method_instance_value : array() );

								foreach ( $shipping_methods as $shipping_method ) {

									foreach ( $shipping_method as $shipping_method_object ) {

										if ( $shipping_method_object->get_instance_id() == $order_shipping_method_instance_id ) { // Checks the instance still exists as might have been deleted (without this as it is still in the term meta until updated the tag would still get set)

											if ( in_array( $order_shipping_method_instance_id, $set_if_shipping_method_instance_value ) ) {

												$set_tag_conditions_met['shipping_method_instance'] = true;

											}

										}

									}

								}

							}

							// Set if shipping zone

							if ( 'on' == $set_if['shipping_zone'] && !empty( $order_shipping_zone ) ) {

								foreach ( $shipping_zones as $shipping_zone ) {

									if ( $shipping_zone['zone_id'] == $order_shipping_zone ) { // Checks the shipping zone still exists as might have been deleted (without this as it is still in the term meta until updated the tag would still get set)

										$set_if_shipping_zone_value = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_shipping_zone_value', true );
										$set_if_shipping_zone_value = ( !empty( $set_if_shipping_zone_value ) ? $set_if_shipping_zone_value : array() );

										if ( in_array( $order_shipping_zone, $set_if_shipping_zone_value ) ) {

											$set_tag_conditions_met['shipping_zone'] = true;

										}

									}

								}

							}

							// Set tag

							if ( !empty( $set_tag_conditions_met ) ) {

								// Set if mode

								$set_if_mode = get_term_meta( $order_tag->term_id, 'wcot_order_tags_set_if_mode', true );

								if ( 'all' == $set_if_mode ) {

									$set_if_ons = array(); // Will get populated with all the set if conditions with on value

									foreach ( $set_if as $set_if_key => $set_if_value ) {

										if ( 'on' == $set_if_value ) {

											$set_if_ons[$set_if_key] = $set_if_value;

										}

									}

									$set_if_ons_count = count( $set_if_ons );
									$set_tag_conditions_met_count = 0;

									foreach ( $set_tag_conditions_met as $set_tag_condition_met_key => $set_tag_condition_met_value ) {

										if ( array_key_exists( $set_tag_condition_met_key, $set_if_ons ) ) {

											$set_tag_conditions_met_count++;

										}

									}

									if ( $set_if_ons_count == $set_tag_conditions_met_count ) {

										wcot_order_tags_set_order_tag( $order_id, $order_tag->term_id );

									}

								} else {

									wcot_order_tags_set_order_tag( $order_id, $order_tag->term_id );

								}

							}

						}

					}

				}

			}

		}

		public function set_tags_order_subscription_renewal( $subscription_renewal_order, $subscription ) {

			if ( !is_object( $subscription_renewal_order ) ) {

				$subscription_renewal_order = wc_get_order( $subscription_renewal_order );

			}

			$this->set_tags( $subscription_renewal_order->get_id(), $subscription_renewal_order );

			return $subscription_renewal_order;

		}

		public function set_tags_bulk() {

			if ( isset( $_GET['wcot_order_tags_set_tags_bulk'] ) ) {

				if ( current_user_can( 'manage_woocommerce' ) ) {

					$set_tags_bulk = sanitize_text_field( $_GET['wcot_order_tags_set_tags_bulk'] );

					if ( '1' == $set_tags_bulk || '2' == $set_tags_bulk ) {

						$orders = wc_get_orders(
							array(
								'limit'		=> -1,
								'return'	=> 'ids',
							)
						);

						if ( !empty( $orders ) ) {

							$order_tags = wcot_order_tags_get_all_order_tags();

							foreach ( $orders as $order_id ) {

								$order = wc_get_order( $order_id );

								if ( '2' == $set_tags_bulk ) { // Removes all existing tags first (this removes any manually added tags)

									foreach ( $order_tags as $order_tag ) {

										wp_remove_object_terms( $order_id, $order_tag->term_id, 'wcot_order_tag' );

									}

								}

								$this->set_tags( $order_id, $order );

							}

							add_action( 'admin_notices', function() { ?>

								<div class="notice notice-success">
									<p><?php esc_html_e( 'Order tags on all orders have been set.', 'wcot-order-tags' ); ?></p>
								</div>

								<?php

							} );

						}

					}

				}

			}

		}

		public function set_tags_operator( $value1, $operator, $value2 ) {

			if ( '=' == $operator ) {

				if ( $value1 == $value2 ) {

					return true;

				} else {

					return false;

				}

			} elseif ( '!=' == $operator ) {

				if ( $value1 !== $value2 ) {

					return true;

				} else {

					return false;

				}

			} elseif ( '>=' == $operator ) {

				if ( $value1 >= $value2 ) {

					return true;

				} else {

					return false;

				}

			} elseif ( '>' == $operator ) {

				if ( $value1 > $value2 ) {

					return true;

				} else {

					return false;

				}

			} elseif ( '<=' == $operator ) {

				if ( $value1 <= $value2 ) {

					return true;

				} else {

					return false;

				}

			} elseif ( '<' == $operator ) {

				if ( $value1 < $value2 ) {

					return true;

				} else {

					return false;

				}

			} elseif ( 'contains' == $operator ) { // This operator is only used for the meta data set if condition

				if ( strpos( $value1, $value2 ) !== false ) {

					return true;
	
				} else {
	
					return false;
	
				}

			} else {

				return false;

			}

		}

	}

}
